import { Rule } from './type'

/**
 *
 * 金额转换，支持小数点，单位，千分位配置
 * @category  format
 * @param {number} m 输入金额
 * @param {Rule} [rule] interface接口，支持是否使用千分位，
 * @returns {(string|number)}
 * @author hzxiongxu
 * @date 20210520
 *
 */
export function moneyFormat(m: number | string, rule?: Rule): string {
  // 默认2位小数加上千分位
  const p: Rule = {
    decimalPlaces: 2,
    useThousands: true,
    unit: '',
    symbol: ''
  }

  const params = { ...p, ...rule }
  let result = '0.00'
  if (m !== null && m !== undefined) {
    const fixedNum = Number(m).toFixed(params.decimalPlaces)
    result = params.useThousands ? fixedNum.replace(/\B(?=(\d{3})+\b)/g, ',') : fixedNum
  }
  return `${params.symbol}${result}${params.unit}`
}

/**
 * 格式化卡号格式：仅数字，4位一空格 （1111 2222 3333）
 * @format  format
 * @param {string} value
 * @param {number} limit
 * @author hzxiongxu
 * @date 20210520
 */
export function cardNoFormat(value: string, limit = 25): string {
  if (value) {
    let formatValue = value.replace(/[^0-9]/g, '')
    if (limit) {
      formatValue = formatValue.length > limit ? formatValue.slice(0, limit) : formatValue
    }
    return formatValue.replace(/(\d{4})(?=.)/g, '$1 ')
  }
  return value
}

/**
 *
 * 格式化手机号格式：仅数字，344分隔 （133 2222 3333）
 * @category format
 * @param {string} value
 * @returns {string}
 * @author hzxiongxu
 * @date 20210520
 *
 */
export function mobileNoFormat(value: string): string {
  if (value) {
    const formatValue = value.replace(/[^0-9]/g, '')
    return formatValue.replace(/(\d{3})(?!$)/, '$1 ').replace(/(\d{4})(?!$)/, '$1 ')
  }
  return value
}
