/**
 *
 * 根据key获取url中的参数，默认从search取,也支持从整个url中获取
 * @category  url
 * @param {string} [url=window.location.href]
 * @param {string} key
 * @returns {string}
 * @author hzxiongxu
 * @date 20210520
 *
 */
export function getUrlParams(key: string, url: string = window.location.href): string {
  const reg = new RegExp(`(^|&|\\?|#)${key}=([^&]*)(&|$|\\?|#)`, 'i')
  const r = url.substr(1).match(reg)
  if (r != null) {
    return decodeURI(r[2])
  }
  return ''
}

/**
 *
 * 获取url所有参数
 * @category  url
 * @param {string} [url=window.location.href]
 * @return {*}  {Record<string, any>}
 * @author hzxiongxu
 * @date 20210520
 */
export function getAllUrlParams(url: string = window.location.href): Record<string, any> {
  let query = []
  const params = {} as any
  if (url.indexOf('?') === -1) {
    query = url.split('&')
  } else {
    query = url.split('?')[1].split('&')
  }
  query.forEach((item: any) => {
    const q = item.split('=')
    if (q.length === 2) {
      params[q[0]] = q[1]
    }
  })
  return params
}
